abacusai.prediction_operator_version — AbacusAI documentation

# `abacusai.prediction_operator_version`

## Module Contents

### Classes

`PredictionOperatorVersion` | A prediction operator version.

class abacusai.prediction_operator_version.PredictionOperatorVersion(client, predictionOperatorId=None, predictionOperatorVersion=None, createdAt=None, updatedAt=None, sourceCode=None, memory=None, useGpu=None, featureGroupIds=None, featureGroupVersions=None, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A prediction operator version.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - predictionOperatorId (str) – The unique identifier of the prediction operator.

    - predictionOperatorVersion (str) – The unique identifier of the prediction operator version.

    - createdAt (str) – Date and time at which the prediction operator was created.

    - updatedAt (str) – Date and time at which the prediction operator was updated.

    - sourceCode (str) – Python code used to make the prediction operator.

    - memory (int) – Memory in GB specified for the prediction operator version.

    - useGpu (bool) – Whether this prediction operator version is using gpu.

    - featureGroupIds (list) – A list of Feature Group IDs used for initializing.

    - featureGroupVersions (list) – A list of Feature Group version IDs used for initializing.

    - codeSource (CodeSource) – If a python model, information on the source code.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  delete()

    Delete a prediction operator version.

    Parameters:

      prediction_operator_version (str) – The unique ID of the prediction operator version.

    Return type:

      PredictionOperatorVersion